@@ -135,13 +135,13 @@ class TDeviceWin(TDeviceBase) :
         return bflag
 
     def Reset(this) :
-        return this.__SendCtrlCmd('RESET')
+        return this.SendCtrlCmd('RESET')
 
     def Next(this) :
-        return this.__SendCtrlCmd('NEXT')
+        return this.SendCtrlCmd('NEXT')
 
     def Back(this) :
-        return this.__SendCtrlCmd('BACK')
+        return this.SendCtrlCmd('BACK')
 
     def ReadReg(this, regAddr, byteOffset, readCount, regValueList, regValueListStartIdx=0) :
         dutIdx = 0
