@@ -45,6 +45,11 @@ class Api :
         this.TDeviceSysSetBoardID.restype=c_int;
         this.TDeviceSysSetBoardID.argtypes=[c_void_p, c_int]
 
+        #TDEVICE_API TED_BOOL TDeviceSysSetTcLocalSave(void* hdl, int boardID, int bFlag);
+        this.TDeviceSysSetTcLocalSave = Load_DLL['TDeviceSysSetTcLocalSave']
+        this.TDeviceSysSetTcLocalSave.restype=c_int;
+        this.TDeviceSysSetTcLocalSave.argtypes=[c_void_p, c_int, c_int]
+
         #TDEVICE_API TED_BOOL TDeviceSysDelay(TDEVICE_HDL hdl, int delay /*unit : milesec*/);
         this.TDeviceSysDelay = Load_DLL['TDeviceSysDelay']
         this.TDeviceSysDelay.restype=c_int;
@@ -275,6 +280,10 @@ class Api :
         this.TDeviceAdcGetInvalidValue.restype=c_int;
         this.TDeviceAdcGetInvalidValue.argtypes=[c_void_p]
 
+        this.TDeviceAdcGetInvalidFloat = Load_DLL['TDeviceAdcGetInvalidFloat']
+        this.TDeviceAdcGetInvalidFloat.restype=c_float;
+        this.TDeviceAdcGetInvalidFloat.argtypes=[c_void_p]
+
         #TDEVICE_API int TDeviceAdcGetGroupCount(void* hdl, int dutIdx);
         this.TDeviceAdcGetGroupCount = Load_DLL['TDeviceAdcGetGroupCount']
         this.TDeviceAdcGetGroupCount.restype=c_int;
@@ -335,6 +344,12 @@ class Api :
         this.TDeviceAdcGetVoltage.restype=c_int;
         this.TDeviceAdcGetVoltage.argtypes=[c_void_p, c_int, c_int, c_int]
 
+        #TDEVICE_API float TDeviceAdcGetVoltFloat(void* hdl, int dutIdx, int groupIdx, int chIdx);
+        this.TDeviceAdcGetVoltFloat = Load_DLL['TDeviceAdcGetVoltFloat']
+        this.TDeviceAdcGetVoltFloat.restype=c_float
+        this.TDeviceAdcGetVoltFloat.argtypes=[c_void_p, c_int, c_int, c_int]
+
+
         #TDEVICE_API int TDeviceAdcGetVoltageByPsID(void* hdl, int dutIdx, int psID);
         this.TDeviceAdcGetVoltageByPsID = Load_DLL['TDeviceAdcGetVoltageByPsID']
         this.TDeviceAdcGetVoltageByPsID.restype=c_int;
@@ -342,7 +357,7 @@ class Api :
 
         #TDEVICE_API float TDeviceAdcGetVoltFloatByPsID(void* hdl, int dutIdx, int psID);
         this.TDeviceAdcGetVoltFloatByPsID = Load_DLL['TDeviceAdcGetVoltFloatByPsID']
-        this.TDeviceAdcGetVoltFloatByPsID.restype=c_int;
+        this.TDeviceAdcGetVoltFloatByPsID.restype=c_float;
         this.TDeviceAdcGetVoltFloatByPsID.argtypes=[c_void_p, c_int, c_int]
 
         #TDEVICE_API TED_BOOL TDeviceAdcGetAllVoltage(void* hdl, int dutIdx, int groupIdx, int* valueArray);
@@ -350,11 +365,22 @@ class Api :
         this.TDeviceAdcGetAllVoltage.restype=c_int;
         this.TDeviceAdcGetAllVoltage.argtypes=[c_void_p, c_int, c_int, c_char_p]
 
+        #TDEVICE_API TED_BOOL TDeviceAdcGetAllVoltFloat(void* hdl, int dutIdx, int groupIdx, float* fvalueArray);
+        this.TDeviceAdcGetAllVoltFloat = Load_DLL['TDeviceAdcGetAllVoltFloat']
+        this.TDeviceAdcGetAllVoltFloat.restype=c_int;
+        this.TDeviceAdcGetAllVoltFloat.argtypes=[c_void_p, c_int, c_int, c_char_p]
+
+
+        #TDEVICE_API int TDeviceAdcGetCurrFloat(void* hdl, int dutIdx, int groupIdx, int chIdx);
+        this.TDeviceAdcGetCurrFloat = Load_DLL['TDeviceAdcGetCurrFloat']
+        this.TDeviceAdcGetCurrFloat.restype=c_float;
+        this.TDeviceAdcGetCurrFloat.argtypes=[c_void_p, c_int, c_int, c_int]
+        
         #TDEVICE_API int TDeviceAdcGetCurrent(void* hdl, int dutIdx, int groupIdx, int chIdx);
         this.TDeviceAdcGetCurrent = Load_DLL['TDeviceAdcGetCurrent']
         this.TDeviceAdcGetCurrent.restype=c_int;
         this.TDeviceAdcGetCurrent.argtypes=[c_void_p, c_int, c_int, c_int]
-        
+
         #TDEVICE_API int TDeviceAdcGetCurrentByPsID(void* hdl, int dutIdx, int psID);
         this.TDeviceAdcGetCurrentByPsID = Load_DLL['TDeviceAdcGetCurrentByPsID']
         this.TDeviceAdcGetCurrentByPsID.restype=c_int;
@@ -362,14 +388,24 @@ class Api :
 
         #TDEVICE_API float TDeviceAdcGetCurrFloatByPsID(void* hdl, int dutIdx, int psID);
         this.TDeviceAdcGetCurrFloatByPsID = Load_DLL['TDeviceAdcGetCurrFloatByPsID']
-        this.TDeviceAdcGetCurrFloatByPsID.restype=c_int;
+        this.TDeviceAdcGetCurrFloatByPsID.restype=c_float;
         this.TDeviceAdcGetCurrFloatByPsID.argtypes=[c_void_p, c_int, c_int]
     
         #TDEVICE_API TED_BOOL TDeviceAdcGetAllCurrent(void* hdl, int dutIdx, int groupIdx, int* valueArray);
         this.TDeviceAdcGetAllCurrent = Load_DLL['TDeviceAdcGetAllCurrent']
         this.TDeviceAdcGetAllCurrent.restype=c_int;
         this.TDeviceAdcGetAllCurrent.argtypes=[c_void_p, c_int, c_int, c_char_p]
-    
+
+        #TDEVICE_API TED_BOOL TDeviceAdcGetAllCurrFloat(void* hdl, int dutIdx, int groupIdx, float* fvalueArray);
+        this.TDeviceAdcGetAllCurrFloat = Load_DLL['TDeviceAdcGetAllCurrFloat']
+        this.TDeviceAdcGetAllCurrFloat.restype=c_int;
+        this.TDeviceAdcGetAllCurrFloat.argtypes=[c_void_p, c_int, c_int, c_char_p]
+
+        #TDEVICE_API TED_BOOL TDeviceAdcGetAllFloat(void* hdl, int dutIdx, int groupIdx, float* fVoltArray, float* fCurrArray)
+        this.TDeviceAdcGetAllFloat = Load_DLL['TDeviceAdcGetAllFloat']
+        this.TDeviceAdcGetAllFloat.restype=c_int;
+        this.TDeviceAdcGetAllFloat.argtypes=[c_void_p, c_int, c_int, c_char_p, c_char_p]
+
         #TDEVICE_API TED_BOOL TDeviceAdcSoutSetRBSel(void* hdl, int dutIdx, int value);
         this.TDeviceAdcSoutSetRBSel = Load_DLL['TDeviceAdcSoutSetRBSel']
         this.TDeviceAdcSoutSetRBSel.restype=c_int;
@@ -544,8 +580,7 @@ class Api :
         this.TDeviceSoutAdcGetAllVoltage = Load_DLL['TDeviceSoutAdcGetAllVoltage']
         this.TDeviceSoutAdcGetAllVoltage.restype=c_int;
         this.TDeviceSoutAdcGetAllVoltage.argtypes=[c_void_p, c_int, c_char_p]
-
-
+                
         #TDEVICE_API int TDeviceLdoAdcSetInConfig(TDEVICE_HDL hdl,  int dutIdx, int chIdx, int value); 
         this.TDeviceLdoAdcSetInConfig = Load_DLL['TDeviceLdoAdcSetInConfig']
         this.TDeviceLdoAdcSetInConfig.restype=c_int;
