@@ -144,14 +144,12 @@ class TDevice :
     def ReadReg(this, regAddr, byteOffset, readCount, regValueList, regValueListStartIdx=0) : 
         
         dutIndex = 0
-        regValueInt = 0
-        regValueByteArray=bytes(readCount)
-        ret = this.__TDevice.DD_DSIM_MipiReadReg(this.__DeviceHandle, regAddr, byteOffset, readCount, regValueByteArray)
-        if ret==1 :
-            for idx, regValueByte in enumerate(regValueByteArray) :
-                regValueInt = regValueByte
-                regValueInt &= 0xFF
-                regValueList[idx + regValueListStartIdx] = regValueInt
+        #regValueList = this.__TDevice.DD_DSIM_MipiReadReg(dutIndex, regAddr, byteOffset, readCount)
+        regValueListTmp = this.DD_DSIM_MipiReadReg(dutIndex, regAddr, byteOffset, readCount)
+
+        if len(regValueList)==readCount :
+            for idx in range(readCount) :
+                regValueList[idx + regValueListStartIdx] = regValueListTmp[idx]
             bflag = True
         else :
             bflag = False;
